@@ -63,10 +63,10 @@ class ApiGatewayToLambda(
         '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
-        :param api_gateway_props: Optional user-provided props to override the default props for the API. Default: - Default props are used.
+        :param api_gateway_props: Optional - user-provided props to override the default props for the API Gateway API. Default: - Default props are used.
         :param create_usage_plan: Whether to create a Usage Plan attached to the API. Must be true if apiGatewayProps.defaultMethodOptions.apiKeyRequired is true Default: - true (to match legacy behavior)
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
-        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used.
+        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` is an error. Default: - Default props are used.
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
 
         :access: public
@@ -133,10 +133,10 @@ class ApiGatewayToLambdaProps:
     ) -> None:
         '''The properties for the ApiGatewayToLambda class.
 
-        :param api_gateway_props: Optional user-provided props to override the default props for the API. Default: - Default props are used.
+        :param api_gateway_props: Optional - user-provided props to override the default props for the API Gateway API. Default: - Default props are used.
         :param create_usage_plan: Whether to create a Usage Plan attached to the API. Must be true if apiGatewayProps.defaultMethodOptions.apiKeyRequired is true Default: - true (to match legacy behavior)
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
-        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used.
+        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` is an error. Default: - Default props are used.
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
         '''
         if isinstance(lambda_function_props, dict):
@@ -164,7 +164,7 @@ class ApiGatewayToLambdaProps:
 
     @builtins.property
     def api_gateway_props(self) -> typing.Any:
-        '''Optional user-provided props to override the default props for the API.
+        '''Optional - user-provided props to override the default props for the API Gateway API.
 
         :default: - Default props are used.
         '''
@@ -198,7 +198,9 @@ class ApiGatewayToLambdaProps:
     def lambda_function_props(
         self,
     ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
-        '''User provided props to override the default props for the Lambda function.
+        '''Optional - user provided props to override the default props for the Lambda function.
+
+        Providing both this and ``existingLambdaObj`` is an error.
 
         :default: - Default props are used.
         '''
